@@ -94,11 +94,21 @@ lxAboutDlg::lxAboutDlg(wxWindow * parent)
   pbmp->SetSize(tmpsize.x - bmp.GetWidth(), tmpsize.y - bmp.GetHeight(), -1, -1);
   this->CentreOnParent();
 
+#if wxCHECK_VERSION(3,0,0)
+  FindWindow(lxABDG_TEXT1)->Bind(wxEVT_KEY_DOWN, &lxAboutDlg::OnKeyPress, this);
+  FindWindow(lxABDG_TEXT2)->Bind(wxEVT_KEY_DOWN, &lxAboutDlg::OnKeyPress, this);
+  FindWindow(lxABDG_TEXT3)->Bind(wxEVT_KEY_DOWN, &lxAboutDlg::OnKeyPress, this);
+  FindWindow(lxABDG_BMP)->Bind(wxEVT_KEY_DOWN, &lxAboutDlg::OnKeyPress, this);
+  FindWindow(lxABDG_TEXT1)->Bind(wxEVT_LEFT_DOWN, &lxAboutDlg::OnMouseDown, this);
+  FindWindow(lxABDG_TEXT2)->Bind(wxEVT_LEFT_DOWN, &lxAboutDlg::OnMouseDown, this);
+  FindWindow(lxABDG_TEXT3)->Bind(wxEVT_LEFT_DOWN, &lxAboutDlg::OnMouseDown, this);
+  FindWindow(lxABDG_BMP)->Bind(wxEVT_LEFT_DOWN, &lxAboutDlg::OnMouseDown, this);
+#else
   FindWindow(lxABDG_TEXT1)->SetEventHandler(this->GetEventHandler());
   FindWindow(lxABDG_TEXT2)->SetEventHandler(this->GetEventHandler());
   FindWindow(lxABDG_TEXT3)->SetEventHandler(this->GetEventHandler());
   FindWindow(lxABDG_BMP)->SetEventHandler(this->GetEventHandler());
-
+#endif
   delete sizerBmp;
 
 }
