@@ -4,12 +4,12 @@
 # Usage: samples.tcl
 #        samples.tcl clean
 
-set outdd "."
+set outdd ".."
 if {[llength $argv] > 0} {
   set outdd [lindex $argv 0]
 }
 
-set outd "../$outdd/samples.doc"
+set outd "$outdd/samples.doc"
 set flog [open samples.log w]
 
 proc log_msg {msg} {
@@ -45,7 +45,7 @@ proc scan_files {dir} {
   }
 }
 
-set thcmd [file normalize [file join [pwd] "../$outdd/therion"]]
+set thcmd [file normalize [file join [pwd] "$outdd/therion"]]
 set processlist {}
 
 proc scan_lists {} {
@@ -302,7 +302,7 @@ proc create_docs {} {
 	  set inparagraph 0
 	}
 	append data($chid,TEXT) "<p>\n<a href=\"$iifnm\"><img border=\"1\" src=\"$iiimg\"/></a>\n</p>\n"
-	append texdata($chid,TEXT) "\n\n\\fitpic{../$outdd/samples.doc/$iifnm}\n\n"
+	append texdata($chid,TEXT) "\n\n\\fitpic{$outdd/samples.doc/$iifnm}\n\n"
 	incr imid
       } elseif {[regexp -nocase {^\s*\#\!HTML\s+(\S.*)$} $ln dum ii]} {
 	set html_src [file join [lindex $fr 1] $ii]
