@@ -407,7 +407,7 @@ class thdataleg {
   unsigned int s_mark,  ///< Type of the station mark
     extend;  ///< Extend flags: normal, reverse, left, right, break
 
-  int walls, shape;
+  int walls, shape, gridcs;
   
   thobjectname station, from, to;
   class thsurvey * psurvey;  ///< parent survey
@@ -447,6 +447,14 @@ class thdataleg {
   void clear();
   
   void calc_total_stds();
+
+
+	/**
+	 * Export station attributes to metapost.
+	 */
+
+	void export_mp_flags(FILE * out);
+
   
 };
 
