@@ -46,7 +46,7 @@ enum {
   TT_UNKNOWN_CMD,
   TT_DATAOBJECT_CMD, TT_DATASTATION_CMD, TT_2DDATAOBJECT_CMD,
   TT_SURVEY_CMD, TT_ENDSURVEY_CMD,
-  TT_GRADE_CMD, TT_LAYOUT_CMD,
+  TT_GRADE_CMD, TT_LAYOUT_CMD, TT_COMMENT_CMD,
   TT_SCRAP_CMD, TT_ENDSCRAP_CMD,
   TT_POINT_CMD, TT_LINE_CMD, TT_AREA_CMD,
   TT_JOIN_CMD, TT_MAP_CMD, TT_SURFACE_CMD,
@@ -62,6 +62,7 @@ static const thstok thtt_commands[] = {
   {"area", TT_AREA_CMD},
   {"centerline", TT_DATA_CMD},
   {"centreline", TT_DATA_CMD},
+  {"comment", TT_COMMENT_CMD},
   {"endscrap", TT_ENDSCRAP_CMD},
   {"endsurvey", TT_ENDSURVEY_CMD},
   {"grade", TT_GRADE_CMD},
