@@ -168,9 +168,9 @@ void thexpmodel::process_db(class thdatabase * dbp)
     case TT_EXPMODEL_FMT_COMPASS:
       this->export_plt_file(dbp);
       break;
-    case TT_EXPMODEL_FMT_THERION:
-      this->export_thm_file(dbp);
-      break;
+    //case TT_EXPMODEL_FMT_THERION:
+    //  this->export_thm_file(dbp);
+    //  break;
     case TT_EXPMODEL_FMT_3DMF:
       this->export_3dmf_file(dbp);
       break;
@@ -348,7 +348,7 @@ void thexpmodel::export_plt_file(class thdatabase * dbp)
 
   unsigned long last_st = nstat, cur_st;
   double xmin = 0.0, xmax = 0.0, ymin = 0.0, ymax = 0.0, 
-    zmin = 0.0, zmax = 0.0, avx, avy, avz;
+    zmin = 0.0, zmax = 0.0;
   
 #define minmaxvar(min,max,var) \
 if (var < min) min = var;\
@@ -379,10 +379,6 @@ if (var > max) max = var
     }
   }
   
-  avx = (xmin + xmax) / 2.0;
-  avy = (ymin + ymax) / 2.0;
-  avz = (zmin + zmax) / 2.0;
-
 #define copy_station_name(stid) \
 strncpy(station_name,dbp->db1d.station_vec[stid].name,8); \
 station_name[8] = 0
@@ -390,8 +386,7 @@ station_name[8] = 0
 #define exppltdim(ffd,ttd) (((*tlegs)->reverse ? thisnan((*tlegs)->leg->ffd) : thisnan((*tlegs)->leg->ttd)) ? -9999.0 : toft((*tlegs)->reverse ? (*tlegs)->leg->ffd : (*tlegs)->leg->ttd))
   
   // now let's print header
-  fprintf(pltf,"Z\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\n\n",toft(ymin-avy),toft(ymax-avy),toft(xmin-avx),toft(xmax-avx),toft(zmin),toft(zmax));
-//  fprintf(pltf,"Z\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\n",toft(ymin-avy),toft(ymax-avy),toft(xmin-avx),toft(xmax-avx),toft(zmin-avz),toft(zmax-avz));
+  fprintf(pltf,"Z\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\n\n",toft(ymin),toft(ymax),toft(xmin),toft(xmax),toft(zmin),toft(zmax));
   fprintf(pltf,"STHERION\n");
   fprintf(pltf,"NX\tD\t3\t12\t1997\tCtherion export\n");
   last_st = nstat;
@@ -402,7 +397,7 @@ station_name[8] = 0
       if (cur_st != last_st) {
         copy_station_name(cur_st);
         fprintf(pltf,"M\t%.2f\t%.2f\t%.2f\tS%s\tP\t%.2f\t%.2f\t%.2f\t%.2f\n",
-          toft(dbp->db1d.station_vec[cur_st].y - avy), toft(dbp->db1d.station_vec[cur_st].x - avx), 
+          toft(dbp->db1d.station_vec[cur_st].y), toft(dbp->db1d.station_vec[cur_st].x), 
           toft(dbp->db1d.station_vec[cur_st].z),station_name,
           exppltdim(to_left, from_left), 
           exppltdim(to_up, from_up), 
@@ -415,18 +410,16 @@ station_name[8] = 0
       if (strcmp(station_name,"VA09") == 0) 
         fflush(pltf);
       fprintf(pltf,"D\t%.2f\t%.2f\t%.2f\tS%s\tP\t%.2f\t%.2f\t%.2f\t%.2f\n",
-        toft(dbp->db1d.station_vec[last_st].y - avy), toft(dbp->db1d.station_vec[last_st].x - avx), 
+        toft(dbp->db1d.station_vec[last_st].y), toft(dbp->db1d.station_vec[last_st].x), 
         toft(dbp->db1d.station_vec[last_st].z),station_name,
         exppltdim(from_left, to_left), 
         exppltdim(from_up, to_up), 
         exppltdim(from_down, to_down), 
         exppltdim(from_right, to_right));
-//        toft(dbp->db1d.station_vec[last_st].z - avz),station_name);
     }
   }
 
-  fprintf(pltf,"X\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\n\x1A",toft(ymin-avy),toft(ymax-avy),toft(xmin-avx),toft(xmax-avx),toft(zmin),toft(zmax));
-//  fprintf(pltf,"X\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\n",toft(ymin-avy),toft(ymax-avy),toft(xmin-avx),toft(xmax-avx),toft(zmin-avz),toft(zmax-avz));
+  fprintf(pltf,"X\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\t%.2f\n\x1A",toft(ymin),toft(ymax),toft(xmin),toft(xmax),toft(zmin),toft(zmax));
   fclose(pltf);
   
 #ifdef THDEBUG
@@ -436,6 +429,7 @@ station_name[8] = 0
 #endif
 }
 
+/*
 void thexpmodel::export_thm_file(class thdatabase * dbp)
 {
 
@@ -461,6 +455,7 @@ void thexpmodel::export_thm_file(class thdatabase * dbp)
   thdb_object_list_type::iterator obi;
   thdb3ddata * pgn = dbp->db1d.get_3d(), 
     * surf_pgn = dbp->db1d.get_3d_surface(),
+		* splay_pgn = dbp->db1d.get_3d_splay(),
     * tmp3d;
   thdb3dlim pgnlimits, finlim;
   switch (this->items & TT_EXPMODEL_ITEM_CENTERLINE) {
@@ -474,6 +469,8 @@ void thexpmodel::export_thm_file(class thdatabase * dbp)
     default:    
       pgnlimits.update(&(pgn->limits));
   }
+	if ((this->items & TT_EXPMODEL_ITEM_SPLAYSHOTS) != 0)
+		pgnlimits.update(&(splay_pgn->limits));
   finlim.update(&(pgnlimits));
 
   // update limits from surfaces
@@ -604,7 +601,7 @@ void thexpmodel::export_thm_file(class thdatabase * dbp)
   thtext_inline = false;
 #endif
 }
-
+*/
 
 void thexpmodel::export_vrml_file(class thdatabase * dbp) {
   const char * fnm;  
@@ -633,6 +630,7 @@ void thexpmodel::export_vrml_file(class thdatabase * dbp) {
   thdb_object_list_type::iterator obi;
   thdb3ddata * pgn = dbp->db1d.get_3d(), 
     * surf_pgn = dbp->db1d.get_3d_surface(),
+		* splay_pgn = dbp->db1d.get_3d_splay(),
     * tmp3d;
   thdb3dlim pgnlimits, finlim;
   switch (this->items & TT_EXPMODEL_ITEM_CENTERLINE) {
@@ -646,6 +644,9 @@ void thexpmodel::export_vrml_file(class thdatabase * dbp) {
     default:    
       pgnlimits.update(&(pgn->limits));
   }
+	if ((this->items & TT_EXPMODEL_ITEM_SPLAYSHOTS) != 0)
+		pgnlimits.update(&(splay_pgn->limits));
+
   finlim.update(&(pgnlimits));
   // now let's print header
   fprintf(pltf,"#VRML V2.0 utf8\n\n");
@@ -668,6 +669,14 @@ void thexpmodel::export_vrml_file(class thdatabase * dbp) {
        surf_pgn->export_vrml(pltf);
     fprintf(pltf,"\n}\n}\n");
   }
+  if ((this->items & TT_EXPMODEL_ITEM_SPLAYSHOTS) != 0) {
+    fprintf(pltf,
+       "Shape {\nappearance Appearance {\n" \
+       "\tmaterial Material {\n\t\temissiveColor 0.22 0.22 0.22\n\t}" \
+       "\n}\ngeometry IndexedLineSet {\n");
+       splay_pgn->export_vrml(pltf);
+    fprintf(pltf,"\n}\n}\n");
+  }
 
   bool has_texture;
   int imgn = 0;
@@ -875,6 +884,7 @@ void thexpmodel::export_3dmf_file(class thdatabase * dbp) {
   thdb_object_list_type::iterator obi;
   thdb3ddata * pgn = dbp->db1d.get_3d(), 
     * surf_pgn = dbp->db1d.get_3d_surface(),
+		* splay_pgn = dbp->db1d.get_3d_splay(),
     * tmp3d;
   thdb3dlim pgnlimits, finlim;
   switch (this->items & TT_EXPMODEL_ITEM_CENTERLINE) {
@@ -888,6 +898,8 @@ void thexpmodel::export_3dmf_file(class thdatabase * dbp) {
     default:    
       pgnlimits.update(&(pgn->limits));
   }
+	if ((this->items & TT_EXPMODEL_ITEM_SPLAYSHOTS) != 0)
+		pgnlimits.update(&(splay_pgn->limits));
   finlim.update(&(pgnlimits));
   avx = (pgnlimits.minx + pgnlimits.maxx) / 2.0;
   avy = (pgnlimits.miny + pgnlimits.maxy) / 2.0;
@@ -913,6 +925,15 @@ void thexpmodel::export_3dmf_file(class thdatabase * dbp) {
       fprintf(pltf,"EndGroup ( )\n");
     }
   }
+  if ((this->items & TT_EXPMODEL_ITEM_SPLAYSHOTS) != 0) {
+    if (pgn->firstfc != NULL) {
+      fprintf(pltf,"BeginGroup (\n\tDisplayGroup ( ) \n)\n"
+              "Container ( \n\tAttributeSet ( ) \n"
+              "\tDiffuseColor ( 0.22 0.22 0.22)\n)\n");
+      splay_pgn->export_3dmf(pltf);
+      fprintf(pltf,"EndGroup ( )\n");
+    }
+  }
   if ((this->items & TT_EXPMODEL_ITEM_SURFACECENTERLINE) != 0) {
     if (surf_pgn->firstfc != NULL) {
       fprintf(pltf,"BeginGroup (\n\tDisplayGroup ( ) \n)\n"
@@ -1069,6 +1090,7 @@ void thexpmodel::export_dxf_file(class thdatabase * dbp) {
   thdb_object_list_type::iterator obi;
   thdb3ddata * pgn = dbp->db1d.get_3d(), 
     * surf_pgn = dbp->db1d.get_3d_surface(),
+    * splay_pgn = dbp->db1d.get_3d_splay(),
     * tmp3d;
   thdb3dlim pgnlimits, finlim, extlim;
   switch (this->items & TT_EXPMODEL_ITEM_CENTERLINE) {
@@ -1082,6 +1104,8 @@ void thexpmodel::export_dxf_file(class thdatabase * dbp) {
     default:    
       pgnlimits.update(&(pgn->limits));
   }
+	if ((this->items & TT_EXPMODEL_ITEM_SPLAYSHOTS) != 0)
+		pgnlimits.update(&(splay_pgn->limits));
   finlim.update(&(pgnlimits));
   avx = 0.0;
   avy = 0.0;
@@ -1258,6 +1282,9 @@ void thexpmodel::export_dxf_file(class thdatabase * dbp) {
   if ((this->items & TT_EXPMODEL_ITEM_CAVECENTERLINE) != 0) {
     pgn->export_dxf(pltf,"CENTERLINE");
   }
+  if ((this->items & TT_EXPMODEL_ITEM_SPLAYSHOTS) != 0) {
+    splay_pgn->export_dxf(pltf,"SPLAY_SHOTS");
+  }
   if ((this->items & TT_EXPMODEL_ITEM_SURFACECENTERLINE) != 0) {
     surf_pgn->export_dxf(pltf,"SURFACE_CENTERLINE");
   }
