@@ -34,12 +34,12 @@
  */
 
 struct thlayout_color {
-  double R, G, B;
+  double R, G, B, A;
   int defined;
-  void parse(char * str);
-  thlayout_color() : R(1.0), G(1.0), B(1.0), defined(false) {}
-  thlayout_color(double v) : R(v), G(v), B(v), defined(false) {}
-  thlayout_color(double r, double g, double b) : R(r), G(g), B(b), defined(false) {}
+  void parse(char * str, bool aalpha = false);
+  thlayout_color() : R(1.0), G(1.0), B(1.0), A(1.0), defined(0) {}
+  thlayout_color(double v) : R(v), G(v), B(v), A(1.0), defined(0) {}
+  thlayout_color(double r, double g, double b) : R(r), G(g), B(b), A(1.0), defined(0) {}
 };
 
 #endif
