@@ -28,6 +28,8 @@
 
 #include "thparse.h"
 #include "therion.h"
+#include "thlang.h"
+#include "thtexfonts.h"
 #include <string.h>
 #include "thinfnan.h"
 #include "thdatabase.h"
@@ -37,6 +39,9 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <math.h>
+#ifdef THMSVC
+#define strcasecmp _stricmp
+#endif
 
 #ifdef HAVE_ROUND
 extern double round(double); /* prototype is often missing... */
@@ -52,7 +57,7 @@ thround(double x) {
 
 thmbuffer thparse_mbuff;
 
-int thmatch_stok(char *buffer, const thstok *tab, int tab_size)
+int thmatch_stok(const char *buffer, const thstok *tab, int tab_size)
 {
   int a = 0, b = tab_size - 1, c, r;
   while (a <= b) {
@@ -68,7 +73,23 @@ int thmatch_stok(char *buffer, const thstok *tab, int tab_size)
 }
 
 
-char * thmatch_tstring(int token, const thstok *tab, int tab_size)
+int thcasematch_stok(const char *buffer, const thstok *tab, int tab_size)
+{
+  int a = 0, b = tab_size - 1, c, r;
+  while (a <= b) {
+    c = unsigned((a + b) / 2);
+    r = strcasecmp(tab[c].s, buffer);
+    if (r == 0) return tab[c].tok;
+    if (r < 0)
+      a = c + 1;
+    else
+      b = c - 1;
+   }
+   return tab[tab_size].tok; /* no match */
+}
+
+
+const char * thmatch_tstring(int token, const thstok *tab, int tab_size)
 {
   int i = 0;
   while ((i < tab_size) && (tab[i].tok != token))
@@ -80,7 +101,7 @@ char * thmatch_tstring(int token, const thstok *tab, int tab_size)
 }
 
 
-void thsplit_word(thbuffer * dword, thbuffer * drest, char * src)
+void thsplit_word(thbuffer * dword, thbuffer * drest, const char * src)
 {
   long srcl = strlen(src),
     idx = 0,
@@ -138,7 +159,7 @@ void thsplit_word(thbuffer * dword, thbuffer * drest, char * src)
 }
 
 
-void thsplit_words(thmbuffer * dest, char * src)
+void thsplit_words(thmbuffer * dest, const char * src)
 {
   long srcl = strlen(src),
     idx = 0,
@@ -203,7 +224,7 @@ void thsplit_strings(thmbuffer * dest, const char * src, const char separator)
 }
 
 
-void thsplit_paths(thmbuffer * dest, char * src, char separator)
+void thsplit_paths(thmbuffer * dest, const char * src, char separator)
 {
   long srcl = strlen(src),
     idx = 0,
@@ -256,7 +277,7 @@ void thsplit_args_postp_quotes(char * buf)
 }
 
 
-void thsplit_args(thmbuffer * dest, char * src)
+void thsplit_args(thmbuffer * dest, const char * src)
 {
   long srcl = strlen(src),
     idx = 0,
@@ -358,10 +379,10 @@ void thsplit_args(thmbuffer * dest, char * src)
 }
 
 
-void thsplit_fpath(thbuffer * dest, char * src)
+void thsplit_fpath(thbuffer * dest, const char * src)
 {
   long len = strlen(src);
-  char * s = src + len++;
+  const char * s = src + len++;
   while ((len > 0) && (*s != '/')) {
     s--;
     len--;
@@ -370,7 +391,7 @@ void thsplit_fpath(thbuffer * dest, char * src)
 }
 
 
-bool th_is_keyword(char * str)
+bool th_is_keyword(const char * str)
 {
   size_t sl = strlen(str), i;
   unsigned char * s = (unsigned char *) str;
@@ -379,7 +400,7 @@ bool th_is_keyword(char * str)
   else
     for(i = 0; i < sl; i++, s++) {
       if ((*s > 96) && (*s < 123)) continue;
-      if ((*s > 64) && (*s < 91)) continue;
+      if ((*s > 64) && (*s < 91)) continue; 
       if ((*s > 46) && (*s < 58)) continue;
       if (*s == 95) continue;
       if ((*s == 45) && (i > 0)) continue;
@@ -389,7 +410,25 @@ bool th_is_keyword(char * str)
 }
 
 
-bool th_is_index(char * str)
+bool th_is_attr_name(const char * str)
+{
+  size_t sl = strlen(str), i;
+  unsigned char * s = (unsigned char *) str;
+  if (sl == 0)
+    return false;
+  else
+    for(i = 0; i < sl; i++, s++) {
+      if ((*s > 47) && (*s < 58)) continue;
+      if ((*s > 64) && (*s < 91)) continue;
+      if ((*s > 96) && (*s < 123)) continue;
+      if ((*s == 95) && (i > 0)) continue;
+      return false;
+    }
+  return true;
+}
+
+
+bool th_is_index(const char * str)
 {
   size_t sl = strlen(str), i;
   unsigned char * s = (unsigned char *) str;
@@ -404,7 +443,7 @@ bool th_is_index(char * str)
 }
 
 
-bool th_is_keyword_list(char * str, char sep)
+bool th_is_keyword_list(const char * str, char sep)
 {
   size_t sl = strlen(str), i;
   unsigned char * s = (unsigned char *) str;
@@ -423,7 +462,7 @@ bool th_is_keyword_list(char * str, char sep)
 }
 
 
-bool th_is_extkeyword(char * str)
+bool th_is_extkeyword(const char * str)
 {
   size_t sl = strlen(str), i;
   unsigned char * s = (unsigned char *) str;
@@ -445,7 +484,7 @@ bool th_is_extkeyword(char * str)
 }
 
 
-void thparse_double(int & sv, double & dv, char * src)
+void thparse_double(int & sv, double & dv, const char * src)
 {
   char * endptr;
   sv = thmatch_token(src, thtt_special_val);
@@ -472,7 +511,7 @@ void thparse_double(int & sv, double & dv, char * src)
 }
 
 
-void thparse_double_dms(int & sv, double & dv, char * src)
+void thparse_double_dms(int & sv, double & dv, const char * src)
 {
   int ssv;
   double dms;
@@ -485,14 +524,14 @@ void thparse_double_dms(int & sv, double & dv, char * src)
       if (thparse_mbuff.get_size() > 1) {
         thparse_double(ssv, dms, thparse_mbuff.get_buffer()[1]);
 //        thprintf("MIN:%lf\n", dms);
-        if ((ssv == TT_SV_NUMBER) && (dms == double(int(dms))) && (dms >= 0.0) && (dv == double(int(dv)))) {
+        if ((ssv == TT_SV_NUMBER) && (dms >= 0.0) && (dv == double(int(dv)))) {
           // ok, mame minuty
           if (dv > 0.0) {
             dv += dms / 60.0;
           } else {
             dv -= dms / 60.0;
           }
-          if (thparse_mbuff.get_size() == 3) {
+          if ((dms == double(int(dms))) && (thparse_mbuff.get_size() == 3)) {
             thparse_double(ssv, dms, thparse_mbuff.get_buffer()[2]);
 //            thprintf("SEC:%lf\n", dms);
             if ((ssv == TT_SV_NUMBER) && (dms >= 0.0)) {
@@ -505,7 +544,7 @@ void thparse_double_dms(int & sv, double & dv, char * src)
               // error
               sv = TT_SV_UNKNOWN;
             }
-          } else if (thparse_mbuff.get_size() > 3) {
+          } else if (thparse_mbuff.get_size() >= 3) {
             // error
             sv = TT_SV_UNKNOWN;
           }
@@ -582,7 +621,7 @@ void thdecode_tcl(thbuffer * dest, const char * src)
   srcp = (unsigned char*) src;
   dstp = (unsigned char*) dest->get_buffer();
   while (srcx < srcln) {
-    if ((*srcp < 32) || (*srcp > 127)) {
+    if ((*srcp < 32) || (*srcp > 127) || (*srcp == '[') || (*srcp == '[') || (*srcp == '"')) {
         *dstp = '\\';
         dstp++;
         num = *srcp / 64;
@@ -609,6 +648,44 @@ void thdecode_tcl(thbuffer * dest, const char * src)
 
 
 
+void thdecode_mp(thbuffer * dest, const char * src)
+{
+  size_t srcln = strlen(src), srcx = 0;
+  unsigned char * srcp, * dstp;
+  dest->guarantee(srcln * 8 + 1);  // check buffer size
+  srcp = (unsigned char*) src;
+  dstp = (unsigned char*) dest->get_buffer();
+  while (srcx < srcln) {
+    if (*srcp < 32) {
+        *dstp = ' ';
+    } else {
+      if (*srcp == '"') {
+        *dstp = '"';
+        dstp++;
+        *dstp = '&';
+        dstp++;
+        *dstp = 'd';
+        dstp++;
+        *dstp = 't';
+        dstp++;
+        *dstp = 't';
+        dstp++;
+        *dstp = 'o';
+        dstp++;
+        *dstp = '&';
+        dstp++;
+      }
+      *dstp = *srcp;  
+    }
+    srcx++;
+    srcp++;
+    dstp++;
+  }
+  // end destination string with 0
+  *dstp = 0;
+}
+
+
 
 void thdecode_tex(thbuffer * dest, const char * src)
 {
@@ -831,7 +908,7 @@ void thdecode_arg(thbuffer * dest, const char * src)
 
 
 
-void thparse_altitude(char * src, double & altv, double & fixv)
+void thparse_altitude(const char * src, double & altv, double & fixv)
 {
 
   thsplit_args(& thdb.db2d.mbf, src);
@@ -877,7 +954,7 @@ void thparse_altitude(char * src, double & altv, double & fixv)
   }
 }
 
-void thparse_image(char * fname, double & width, double & height, double & dpi, int & type)
+void thparse_image(const char * fname, double & width, double & height, double & dpi, int & type)
 {
 
   type = TT_IMG_TYPE_UNKNOWN;
@@ -918,12 +995,33 @@ void thparse_image(char * fname, double & width, double & height, double & dpi,
       if (dpi < 1.0) {
         dpi = 300.0;
       }      
-      for(sx = 0, scan = &(picth[0]); sx < (phsize - 10); sx++, scan++) {
-        if ((scan[0] == 0xFF) && ((scan[1] == 0xC0) || (scan[1] == 0xC1))) {
-          height = thround(double(scan[5]) * 256.0 + double(scan[6]));
-          width = thround(double(scan[7]) * 256.0 + double(scan[8]));
-        }
+      //for(sx = 0, scan = &(picth[0]); sx < (phsize - 10); sx++, scan++) {
+      //  if ((scan[0] == 0xFF) && ((scan[1] == 0xC0) || (scan[1] == 0xC1))) {
+      //    height = thround(double(scan[5]) * 256.0 + double(scan[6]));
+      //    width = thround(double(scan[7]) * 256.0 + double(scan[8]));
+      //  }
+      //}
+      sx = 0;
+      int marker;
+      size_t len;
+      pictf = fopen(fname, "rb");      
+      fread(&(picth[0]), 1, 2, pictf);
+      height = -1.0;
+      width = -1.0;
+      while(getc(pictf) == 255) {
+        marker = getc(pictf);
+        len = 256 * (size_t) getc(pictf) + (size_t) getc(pictf);
+        if ((marker == 0xC0) || (marker == 0xC1)) {
+          getc(pictf);
+          height = thround(double(getc(pictf)) * 256.0 + double(getc(pictf)));
+          width = thround(double(getc(pictf)) * 256.0 + double(getc(pictf)));
+          break;
+        } 
+        fseek(pictf, len - 2, SEEK_CUR);
       }
+      fclose(pictf);
+      if ((height < 0.0) || (width < 0.0))
+        ththrow(("unable to determine image size -- %s", fname));
     } else if (
       (picth[0] == 0x89) && (picth[1] == 0x50) &&
       (picth[2] == 0x4E) && (picth[3] == 0x47) &&
@@ -1050,5 +1148,133 @@ const char * thutf82xhtml(const char * src)
   
 }
 
+static const char base64_tab[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+
+void thbase64_encode(const char * fname, FILE * fout) {
+  int llength = 0;
+  char in_buffer[3];
+  unsigned char out_buffer[5];
+  out_buffer[4] = 0;
+  FILE * fin;
+  fin = fopen(fname, "rb");
+  size_t count;
+  do {
+    for (int i = 0; i < 3; i++) in_buffer[i] = '\x0';
+    for (int i = 0; i < 4; i++) out_buffer[i] = '=';
+    if (fin != NULL)
+      count = fread(in_buffer, 1, 3, fin);
+    else
+      count = 0;
+    unsigned long value = 
+      ((unsigned char)in_buffer[0]) << 16 |
+      ((unsigned char)in_buffer[1]) << 8 |
+      ((unsigned char)in_buffer[2]) << 0;
+    out_buffer[0] = base64_tab[(value >> 18) & 0x3F];
+    out_buffer[1] = base64_tab[(value >> 12) & 0x3F];
+    if (count > 1) out_buffer[2] = base64_tab[(value >> 6) & 0x3F];
+    if (count > 2) out_buffer[3] = base64_tab[(value >> 0) & 0x3F];
+    if (llength >= 76) {
+      fprintf(fout,"\n");
+      llength = 0;
+    }
+    fprintf(fout,"%s",out_buffer);
+    llength += 4;
+  } while ((fin != NULL) && (!feof(fin)));
+  if (fin != NULL)
+    fclose(fin);
+}
+
+bool thpath_is_absolute(const char * fname)
+{
+#ifdef THWIN32
+  return ((strlen(fname) > 3) && (fname[1] == ':'));
+#else
+  return ((strlen(fname) > 2) && (fname[0] == '/'));
+#endif
+}
 
 
+void thparse_length(int & sv, double & dv, const char * src)
+{
+
+  sv = thmatch_token(src, thtt_special_val);
+  if (sv == TT_SV_NAN) {
+    dv = thnan;
+    return;
+  } else {
+    sv = TT_SV_UNKNOWN;
+  }
+  
+  char * units;
+  size_t strl, cx;
+  strl = strlen(src);
+  thtflength lt;
+  static thbuffer plb;
+  char * srcb;
+  
+  plb.strcpy(src);  
+  srcb = plb.get_buffer();
+    
+  // first let's find units index
+  bool has_units = false;
+  units = NULL;
+  for(cx = strl - 1; cx > 0; cx--) {
+    if (has_units) {
+      if (srcb[cx] < 33) srcb[cx] = 0;
+      else break;
+    } else {
+      if ((cx < strl - 1) && (!(
+                            ((srcb[cx] >= 'a') && (srcb[cx] <= 'z')) || 
+	                          ((srcb[cx] >= 'A') && (srcb[cx] <= 'Z'))
+                          ))
+        ) {
+          units = &(srcb[cx+1]);
+          if (((*units >= 'a') && (*units <= 'z')) || ((*units >= 'A') && (*units <= 'Z'))) {
+            has_units = true;
+          } else {
+            units = NULL;
+          }
+      }
+      if (srcb[cx] < 33) srcb[cx] = 0;
+    }
+  }
+
+  // parse units if applicable
+  if (units != NULL) {
+    lt.parse_units(units);
+    *units = 0;
+  }
+  
+  // parse double value
+  errno = 0;
+  char * endptr;
+  dv = strtod(srcb,&endptr);
+  if ((*endptr == 0) && (errno == 0))
+    sv = TT_SV_NUMBER;
+  else
+    dv = thnan;
+
+  dv = lt.transform(dv);
+  
+}
+
+
+std::string ths2tex(std::string original, int lang, bool remove_kerning)
+{
+  return utf2tex(select_lang(original, thlang_getid(lang)), remove_kerning);
+}
+
+
+
+std::string ths2txt(const char * original, int lang, int encoding)
+{
+  return ths2txt(std::string(original == NULL ? "" : original), lang, encoding);
+}
+
+
+std::string ths2txt(std::string original, int lang, int encoding)
+{
+  // TODO: encoding conversion & al.
+  return select_lang(original, thlang_getid(lang));
+}
+
